@@ -1,3 +1,15 @@
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
+
 """Output formatters using prettytable.
 """
 
@@ -6,7 +18,7 @@ import six
 import os
 
 from cliff import utils
-from .base import ListFormatter, SingleFormatter
+from . import base
 from cliff import columns
 
 
@@ -21,7 +33,7 @@ def _format_row(row):
     return new_row
 
 
-class TableFormatter(ListFormatter, SingleFormatter):
+class TableFormatter(base.ListFormatter, base.SingleFormatter):
 
     ALIGNMENTS = {
         int: 'r',
